pop<T> method
void
pop<T>([
- T? result
Pop the current screen and return to the previous one.
Implementation
void pop<T>([T? result]) {
Navigator.of(this).pop(result);
}
Pop the current screen and return to the previous one.
void pop<T>([T? result]) {
Navigator.of(this).pop(result);
}