EaseXList<T> extension

on

Methods

chunk(int size) List<List<T>>

Available on List<T>, provided by the EaseXList extension

Splits the list into chunks of the given size.
removeDuplicates() List<T>

Available on List<T>, provided by the EaseXList extension

Removes duplicate elements from the list.
safeGet(int index) → T?

Available on List<T>, provided by the EaseXList extension

Returns the element at index or null if the index is out of range.
sortBy<R extends Comparable<R>>(R selector(T item), {bool ascending = true}) List<T>

Available on List<T>, provided by the EaseXList extension

Sorts a list based on a given property.
toMap<K>(K keySelector(T item)) Map<K, T>

Available on List<T>, provided by the EaseXList extension

Converts a list into a map using a key selector.