FileType enum

Inheritance
Available extensions

Values

text → const FileType
pdf → const FileType
png → const FileType
jpg → const FileType
jpeg → const FileType
gif → const FileType
webp → const FileType
bmp → const FileType
mp4 → const FileType
mov → const FileType
avi → const FileType
mkv → const FileType
flv → const FileType
mp3 → const FileType
wav → const FileType
aac → const FileType
ogg → const FileType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FileType>
A constant List of the values in this enum, in order of their declaration.