EaseXShare class

Constructors

EaseXShare()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

openWhatsAppChat(String countryCode, String phoneNumber, {String message = ""}) Future<void>
Open WhatsApp chat with a specific phone number and optinal message.
shareFile(File file, {String? text}) Future<void>
Share File via different applications.
shareMultipleImages(List<File> imageFiles, {String? text}) Future<void>
Share multiple images
shareSingleImage(File imageFile, {String? text}) Future<void>
Share a single image file
shareText(String text) Future<void>
Share text via different applications.
shareVideo(File videoFile) Future<void>
Share Video via different applications.