EaseXValidator class

Constructors

EaseXValidator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validateAge(int? age, {int min = 18, int max = 120}) String?
Validate age
validateCreditCard(String? value) String?
Validate credit card number
validateCVV(String? value) String?
Validate CVV/CVC
validateEmail(String? value) String?
validateEmptyText(String? fieldName, String? value) String?
validateExpiryDate(String? value) String?
Validate credit card expiry date (MM/YY format)
validateNumber(String? value, {double? min, double? max, bool allowDecimals = true}) String?
Validate numeric input
validatePassword(String? value, {int minLength = 6, bool requireUppercase = true, bool requireLowercase = true, bool requireNumbers = true, bool requireSpecialChars = false}) String?
validatePhoneNumber(String? value, {String countryCode = 'US', bool allowInternational = false}) String?
validatePostalCode(String? value, {String countryCode = 'US'}) String?
Validate postal code
validateURL(String? value) String?
Validate URL
validateUsername(String? value, {int minLength = 3, int maxLength = 20}) String?
Validate username