EaseXList<T> extension
- on
-
- List<
T>
- List<
Methods
-
chunk(
int size) → List< List< T> > -
Available on List<
Splits the list into chunks of the givenT> , provided by the EaseXList extensionsize. -
removeDuplicates(
) → List< T> - Removes duplicate elements from the list.
-
safeGet(
int index) → T? -
Available on List<
Returns the element atT> , provided by the EaseXList extensionindexor null if the index is out of range. -
sortBy<
R extends Comparable< (R> >R selector(T item), {bool ascending = true}) → List< T> - Sorts a list based on a given property.
-
toMap<
K> (K keySelector(T item)) → Map< K, T> - Converts a list into a map using a key selector.