EaseXTimeBuilder class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- EaseXTimeBuilder
- Available extensions
Constructors
- EaseXTimeBuilder({Key? key, required DateTime date, required Widget builder(String value), String? locale, TextStyle? style, TextAlign? textAlign, TextOverflow? overflow, int maxLines = 1, TextDirection? textDirection})
-
const
Properties
- builder → Widget Function(String value)
-
final
- date → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- locale → String?
-
final
- maxLines → int
-
final
- overflow → TextOverflow?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → TextStyle?
-
final
- textAlign → TextAlign?
-
final
- textDirection → TextDirection?
-
final
Methods
-
bounce(
{Duration duration = const Duration(milliseconds: 800)}) → Widget -
Available on Widget, provided by the EaseXAnimation extension
Bounce animation -
centered(
) → Widget -
Available on Widget, provided by the EaseXWidgetExtensions extension
Center the widget -
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → _EaseXTimeBuilderState -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
expanded(
{int flex = 1}) → Widget -
Available on Widget, provided by the EaseXWidgetExtensions extension
Wrap with Expanded -
fadeIn(
{Duration duration = const Duration(milliseconds: 300), Duration delay = Duration.zero}) → Widget -
Available on Widget, provided by the EaseXAnimation extension
Fade in animation -
flexible(
{int flex = 1, FlexFit fit = FlexFit.loose}) → Widget -
Available on Widget, provided by the EaseXWidgetExtensions extension
Wrap with Flexible -
margin(
{double all = 0, double horizontal = 0, double vertical = 0, double left = 0, double right = 0, double top = 0, double bottom = 0}) → Widget -
Available on Widget, provided by the EaseXWidgetExtensions extension
Apply margin -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onPressed(
VoidCallback onTap) → Widget -
Available on Widget, provided by the EaseXWidgetExtensions extension
Wrap with GestureDetector -
onTap(
VoidCallback onTap, {BorderRadius? borderRadius}) → Widget -
Available on Widget, provided by the EaseXWidgetExtensions extension
Wrap with InkWell for quick tap detection -
opacity(
double value) → Widget -
Available on Widget, provided by the EaseXWidgetExtensions extension
Apply opacity -
pad(
{double all = 0, double horizontal = 0, double vertical = 0, double left = 0, double right = 0, double top = 0, double bottom = 0}) → Widget -
Available on Widget, provided by the EaseXWidgetExtensions extension
Apply padding -
rotate(
double angle) → Widget -
Available on Widget, provided by the EaseXWidgetExtensions extension
Rotate widget -
rotateIn(
{Duration duration = const Duration(milliseconds: 300), double beginAngle = 0.0, double endAngle = 1.0}) → Widget -
Available on Widget, provided by the EaseXAnimation extension
Rotation animation -
scale(
double factor) → Widget -
Available on Widget, provided by the EaseXWidgetExtensions extension
Scale widget -
scaleIn(
{Duration duration = const Duration(milliseconds: 300), double beginScale = 0.0, double endScale = 1.0}) → Widget -
Available on Widget, provided by the EaseXAnimation extension
Scale animation -
shadow(
{double blur = 5.0, double spread = 1.0, Color color = Colors.black26}) → Widget -
Available on Widget, provided by the EaseXWidgetExtensions extension
Apply shadow -
shake(
{Duration duration = const Duration(milliseconds: 500)}) → Widget -
Available on Widget, provided by the EaseXAnimation extension
Shake animation -
shimmer(
{Color baseColor = const Color(0xFFE0E0E0), Color highlightColor = const Color(0xFFF5F5F5), Duration period = const Duration(seconds: 2), bool enabled = true}) → Widget -
Available on Widget, provided by the EaseXWidgetExtensions extension
Shimmer Effect -
showIf(
bool condition) → Widget -
Available on Widget, provided by the EaseXWidgetExtensions extension
Show/Hide conditionally -
slideInFromBottom(
{Duration duration = const Duration(milliseconds: 300), double offset = 100.0}) → Widget -
Available on Widget, provided by the EaseXAnimation extension
Slide in from bottom animation -
slideInFromLeft(
{Duration duration = const Duration(milliseconds: 300), double offset = 100.0}) → Widget -
Available on Widget, provided by the EaseXAnimation extension
Slide in from left animation -
slideInFromRight(
{Duration duration = const Duration(milliseconds: 300), double offset = 100.0}) → Widget -
Available on Widget, provided by the EaseXAnimation extension
Slide in from right animation -
slideInFromTop(
{Duration duration = const Duration(milliseconds: 300), double offset = 100.0}) → Widget -
Available on Widget, provided by the EaseXAnimation extension
Slide in from top animation -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited