EaseXMedia class
πΈπΉπ Media Picker Utility (Images, Videos, Files) Usage:
- Images:
EaseXMedia.pickImage() - Videos:
EaseXMedia.pickVideo() - Files:
EaseXMedia.pickFile()
Constructors
Properties
- hashCode β int
-
The hash code for this object.
no setterinherited
- runtimeType β Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) β dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) β String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) β bool -
The equality operator.
inherited
Static Methods
-
pickFile(
{List< String> ? allowedExtensions, String? dialogTitle, int? maxSizeInBytes}) β Future<File?> - --- FILE PICKER --- /// π Pick any file (PDF, DOC, etc.) with optional file type filtering.
-
pickImage(
{ImageSource source = ImageSource.gallery, Color? toolbarColor}) β Future< File?> - --- IMAGE PICKER --- ///
-
pickMultipleFiles(
{FileType fileType = FileType.image}) β Future< List< File> ?> - --- MULTIPLE FILES --- /// ποΈ Pick multiple files (images/docs).
-
pickVideo(
{ImageSource source = ImageSource.gallery}) β Future< File?> - --- VIDEO PICKER --- /// π₯ Pick a video from gallery/camera.